package net.wanji.opt.controllerv2.evaluation;

import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.i18n.I18nResourceBundle;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.po.CrossDataHistPO;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.areaproblem.AreaProblemOverview;
import net.wanji.opt.entity.judgeanalysis.AnalysisProblemCrossDay;
import net.wanji.opt.servicev2.evaluation.EvaluationInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;
import java.util.List;
import java.util.Map;

@RestController
@Slf4j
@RequestMapping("/evaluation-info")
@Api(value="EvaluationInfoController", description="方案评价信息接口", tags = "方案评价信息")
public class EvaluationInfoController {

    @Autowired
    EvaluationInfoService evaluationInfoService;
    @ApiOperation(value = "方案评价-总结",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String"),
            @ApiImplicitParam(name = "startTime", value = "分析时段开始时间", required = false, dataType = "string"),
            @ApiImplicitParam(name = "endTime", value = "分析时段截止时间", required = false, dataType = "string"),
            @ApiImplicitParam(name = "contrastStartTime", value = "对比时段开始时间", required = false, dataType = "string"),
            @ApiImplicitParam(name = "constrastEndTime", value = "对比时段截止时间", required = false, dataType = "string"),
    })
    @GetMapping(value = "/overview")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaProblemOverview.class),
    })
    public JsonViewObject problemOverview(String crossId,String startTime, String endTime,String contrastStartTime,String constrastEndTime) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        try{
            Map<String,Object> resData=evaluationInfoService.getListEvaluationSummarize(crossId,startTime,endTime,contrastStartTime,constrastEndTime);
            jsonViewObject.success(resData);
        }catch (Exception e){
            jsonViewObject.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonViewObject;
    }

    @ApiOperation(value = "方案评价-溢出",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String"),
            @ApiImplicitParam(name = "startTime", value = "分析时段开始时间", required = false, dataType = "string"),
            @ApiImplicitParam(name = "endTime", value = "分析时段截止时间", required = false, dataType = "string"),
            @ApiImplicitParam(name = "contrastStartTime", value = "对比时段开始时间", required = false, dataType = "string"),
            @ApiImplicitParam(name = "constrastEndTime", value = "对比时段截止时间", required = false, dataType = "string"),
    })
    @GetMapping(value = "/overFlow")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaProblemOverview.class),
    })
    public JsonViewObject summaryEvaluation(String crossId,String startTime, String endTime,String contrastStartTime,String constrastEndTime) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        try{
            Map<String,Object> resData=evaluationInfoService.summaryEvaluation(crossId,startTime,endTime,contrastStartTime,constrastEndTime);
            jsonViewObject.success(resData);
        }catch (Exception e){
            jsonViewObject.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonViewObject;
    }

    @ApiOperation(value = "方案评价-失衡",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String"),
            @ApiImplicitParam(name = "startTime", value = "分析时段开始时间", required = false, dataType = "string"),
            @ApiImplicitParam(name = "endTime", value = "分析时段截止时间", required = false, dataType = "string"),
            @ApiImplicitParam(name = "contrastStartTime", value = "对比时段开始时间", required = false, dataType = "string"),
            @ApiImplicitParam(name = "constrastEndTime", value = "对比时段截止时间", required = false, dataType = "string"),
    })
    @GetMapping(value = "/unbalance")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaProblemOverview.class),
    })
    public JsonViewObject unbalanceEvaluation(String crossId,String startTime, String endTime,String contrastStartTime,String constrastEndTime) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        try{
            Map<String,Object> resData=evaluationInfoService.unbalanceEvaluation(crossId,startTime,endTime,contrastStartTime,constrastEndTime);
            jsonViewObject.success(resData);
        }catch (Exception e){
            jsonViewObject.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonViewObject;
    }

    @ApiOperation(value = "方案评价-空放",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String"),
            @ApiImplicitParam(name = "startTime", value = "分析时段开始时间", required = false, dataType = "string"),
            @ApiImplicitParam(name = "endTime", value = "分析时段截止时间", required = false, dataType = "string"),
            @ApiImplicitParam(name = "contrastStartTime", value = "对比时段开始时间", required = false, dataType = "string"),
            @ApiImplicitParam(name = "constrastEndTime", value = "对比时段截止时间", required = false, dataType = "string"),
    })
    @GetMapping(value = "/idle")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaProblemOverview.class),
    })
    public JsonViewObject idleEvaluation(String crossId,String startTime, String endTime,String contrastStartTime,String constrastEndTime) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        try{
            Map<String,Object> resData=evaluationInfoService.idleEvaluation(crossId,startTime,endTime,contrastStartTime,constrastEndTime);
            jsonViewObject.success(resData);
        }catch (Exception e){
            jsonViewObject.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonViewObject;
    }


}
