package net.wanji.opt.controllerv2.evaluation;

import net.wanji.common.framework.Constants;
import net.wanji.common.framework.dubbointerface.BaseDubboInterface;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.common.framework.rest.AbstractRestServer;
import net.wanji.common.framework.dubbointerface.BaseDubboInterface;
import net.wanji.common.framework.exception.DubboProviderException;
import net.wanji.common.framework.i18n.I18nResourceBundle;
import net.wanji.common.framework.rest.AbstractRestServer;
import net.wanji.common.framework.rest.impl.AbstractRestServerImpl;
import net.wanji.opt.servicev2.evaluation.EventInfoService;
import net.wanji.opt.entity.evaluation.EventInfo;
import net.wanji.common.framework.rest.Page;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiImplicitParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.google.common.collect.Maps;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import javax.ws.rs.core.MediaType;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 交通事件信息 接口API
 * </p>
 *  @version 1.0
 * @author wangtao
 * @Date 2025-03-18
 */
@RestController
@Slf4j
@RequestMapping("/event-info")
@Api(value="EventInfoController", description="交通事件信息接口", tags = "交通事件信息")
public class EventInfoController extends AbstractRestServerImpl<EventInfo> implements AbstractRestServer<EventInfo>{

    @Autowired
    private EventInfoService eventInfoService;

    @Override
    public EventInfoService getBaseDubboInterface() {
        return this.eventInfoService;
    }


    /**
    * 获取所有交通事件信息记录
    *
    * @return JsonViewObject
    */
    @ApiOperation(value = "交通事件信息-获取所有记录", notes = "获取所有交通事件信息记录", response = EventInfo.class, produces = MediaType.APPLICATION_JSON,hidden = true)
    @GetMapping(value = "/byAll", produces = MediaType.APPLICATION_JSON)
    @Override
    public JsonViewObject getAll() {
        JsonViewObject jsonView = JsonViewObject.newInstance();
        long start=System.currentTimeMillis();

        try {
            List<EventInfo> list = this.getBaseDubboInterface().findAll();
            jsonView.success(list);
        } catch (DubboProviderException e) {
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
            return jsonView;
    }


    @ApiOperation(value = "交通事件信息-根据开始以及结束时间查询交通事件信息", notes = "获取所有交通事件信息记录", response = EventInfo.class, produces = MediaType.APPLICATION_JSON,hidden = false)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "startTime", value = "开始时间", required = true, dataType = "String",defaultValue = ""),
            @ApiImplicitParam(name = "endTime", value = "结束时间", required = true, dataType = "String",defaultValue = ""),
            @ApiImplicitParam(name = "crossId", value = "路口id", required = true, dataType = "String",defaultValue = ""),
    })
    @GetMapping(value = "getListByStartAndEnd")
    public JsonViewObject getListByStartAndEnd(String startTime, String endTime, String crossId){
        JsonViewObject jsonView = JsonViewObject.newInstance();
        long start=System.currentTimeMillis();
        Map<String, Object> map = new HashMap<>();
        map.put("startTime",startTime);
        map.put("endTime",endTime);
        map.put("crossId",crossId);
        try {
            List<Map<String,Object>> list = this.getBaseDubboInterface().getListByStartAndEnd(map);
            jsonView.success(list);
        } catch (Exception e) {
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonView;
    }


    /**
    * 根据id查询交通事件信息记录
    *
    * @param id
    * @return JsonViewObject
    */
    @ApiOperation(value = "交通事件信息-根据id查询记录", notes = "根据id查询交通事件信息记录", response = EventInfo.class, produces = MediaType.APPLICATION_JSON,hidden = true)
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON)
    @Override
    public JsonViewObject getById(@PathVariable String id) {
        JsonViewObject jsonView = JsonViewObject.newInstance();
        long start=System.currentTimeMillis();

        try {
            EventInfo entity = this.getBaseDubboInterface().findById(id);
            jsonView.success(entity);
        } catch (DubboProviderException e) {
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("AbstractRestServerImpl getById error, id:{}", id, e);
        }
        return jsonView;
    }

    @ApiOperation(value = "交通事件信息-根据条件查询记录", notes = "根据条件查询记录", consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/byCondition", produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @Override
    public JsonViewObject getByWhere(@RequestBody EventInfo entity) {
        return  super.getByWhere(entity);
    }

    @ApiOperation(value = "交通事件信息-根据条件分页查询记录", notes = "根据条件分页查询记录",  produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = true)
    @PostMapping(value = "/byPage", produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ResponseBody
    public  JsonViewObject getPage(@RequestBody Page<EventInfo> page){
        return  super.getPage(page);
    }


    /**
    * 根据id删除
    *
    * @param ids
    * @return JsonViewObject
    */
    @ApiOperation(value = "交通事件信息-根据多个id删除记录", notes = "根据多个id删除记录", response = JsonViewObject.class, produces = MediaType.APPLICATION_JSON ,hidden = true)
    @ApiImplicitParams(value = {
    @ApiImplicitParam(paramType = "query", name = "ids", dataType = "String", required = true, value = "多个记录id，用逗号分隔", example = "1,2")
    })
    @GetMapping(value = "/deleting", produces = MediaType.APPLICATION_JSON)
    public JsonViewObject deleteByIds(String ids) {
         return  super.deleteByIds(ids);
    }

    /**
    * 新建记录
    *
    * @param entity
    * @return JsonViewObject
    */
    @ApiOperation(value = "交通事件信息-新建记录", notes = "新建记录", response = JsonViewObject.class, produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = true)
    @PostMapping(value = "/creating", produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject save( @RequestBody EventInfo entity){
        return  super.save(entity);
    }

    /**
    * 修改记录
    *
    * @param entity
    * @return
    */
    @ApiOperation(value = "交通事件信息-修改记录", notes = "修改记录", response = JsonViewObject.class, produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = true)
    @PostMapping(value = "/updating", produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public  JsonViewObject update(@RequestBody EventInfo entity){
        return  super.update(entity);
    }

}
